pub enum AgentToolExecutionMode {
Parallel,
Sequential,
}Expand description
Runtime scheduling mode for a batch of model-returned tool calls.
Variants
Parallel
Execute independent tool calls concurrently when no tool requests sequential execution.
Sequential
Execute tool calls one at a time in model-returned order.