pub struct AgentOverride { /* private fields */ }Expand description
Scoped agent override builder.
Implementations
Sourceimpl AgentOverride
impl AgentOverride
Sourcepub fn model(self, model: Arc<dyn ModelAdapter>) -> Self
pub fn model(self, model: Arc<dyn ModelAdapter>) -> Self
Override the model adapter.
Sourcepub fn model_settings(self, settings: Option<ModelSettings>) -> Self
pub fn model_settings(self, settings: Option<ModelSettings>) -> Self
Override model settings.
Sourcepub fn request_params(self, params: ModelRequestParameters) -> Self
pub fn request_params(self, params: ModelRequestParameters) -> Self
Override request parameters.
Sourcepub fn with_tools(self, tools: ToolRegistry) -> Self
pub fn with_tools(self, tools: ToolRegistry) -> Self
Override runtime tools.
Sourcepub fn toolset(self, toolset: &DynToolset) -> Self
pub fn toolset(self, toolset: &DynToolset) -> Self
Add one runtime toolset to the overridden agent clone.
Sourcepub fn append_tools(self, tools: &ToolRegistry) -> Self
pub fn append_tools(self, tools: &ToolRegistry) -> Self
Merge runtime tools from another registry into the overridden agent clone.
Sourcepub const fn usage_limits(self, limits: Option<UsageLimits>) -> Self
pub const fn usage_limits(self, limits: Option<UsageLimits>) -> Self
Override usage limits.
Sourcepub fn with_instructions(self, instructions: Vec<String>) -> Self
pub fn with_instructions(self, instructions: Vec<String>) -> Self
Override static instructions.
Sourcepub fn append_instructions(
self,
instructions: impl IntoIterator<Item = String>,
) -> Self
pub fn append_instructions( self, instructions: impl IntoIterator<Item = String>, ) -> Self
Append static instructions to the overridden agent clone.
Sourcepub fn dynamic_instructions(
self,
instructions: Vec<DynDynamicInstruction>,
) -> Self
pub fn dynamic_instructions( self, instructions: Vec<DynDynamicInstruction>, ) -> Self
Override dynamic instructions.
Sourcepub fn output_schema(self, schema: Option<OutputSchema>) -> Self
pub fn output_schema(self, schema: Option<OutputSchema>) -> Self
Override structured output schema.
Sourcepub fn output_policy(self, policy: OutputPolicy) -> Self
pub fn output_policy(self, policy: OutputPolicy) -> Self
Apply a complete output policy to the overridden agent clone.
Sourcepub fn output_validators(
self,
validators: Vec<Arc<dyn OutputValidator>>,
) -> Self
pub fn output_validators( self, validators: Vec<Arc<dyn OutputValidator>>, ) -> Self
Override output validators.
Sourcepub fn output_functions(self, functions: Vec<DynOutputFunction>) -> Self
pub fn output_functions(self, functions: Vec<DynOutputFunction>) -> Self
Override output functions.
Sourcepub fn capabilities(self, capabilities: Vec<Arc<dyn AgentCapability>>) -> Self
pub fn capabilities(self, capabilities: Vec<Arc<dyn AgentCapability>>) -> Self
Override capabilities.
Sourcepub fn executor(self, executor: DynAgentExecutor) -> Self
pub fn executor(self, executor: DynAgentExecutor) -> Self
Override durable executor.
Sourcepub fn capability_bundle(self, bundle: &dyn CapabilityBundle) -> Self
pub fn capability_bundle(self, bundle: &dyn CapabilityBundle) -> Self
Apply a capability bundle to the overridden agent clone.
Sourcepub const fn policy(self, policy: AgentRuntimePolicy) -> Self
pub const fn policy(self, policy: AgentRuntimePolicy) -> Self
Override runtime policy.