pub struct AgentResumeCursor {
pub model_request_attempt: usize,
pub tool_call_batch_id: Option<String>,
pub output_validation_attempt: usize,
pub stream_cursor: Option<usize>,
pub message_cursor: usize,
}Expand description
Compact cursor values durable stores use to resume and audit a run.
Fields
model_request_attempt: usizeIndex of the next model request attempt.
tool_call_batch_id: Option<String>Current tool call batch identifier when the run is inside a tool boundary.
output_validation_attempt: usizeIndex of the next output validation attempt.
stream_cursor: Option<usize>Cursor of the last persisted stream event.
message_cursor: usizeLast canonical message index persisted by the runtime.