pub trait AgentExecutor: Send + Sync {
// Required method
fn checkpoint<'life0, 'async_trait>(
&'life0 self,
checkpoint: AgentCheckpoint,
) -> Pin<Box<dyn Future<Output = Result<AgentExecutionDecision, AgentExecutorError>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
// Provided method
fn requires_durable_hitl_preparation(&self) -> bool { ... }
}Expand description
Callback contract for persistence, interruption, and durable scheduling.
Required Methods
Sourcefn checkpoint<'life0, 'async_trait>(
&'life0 self,
checkpoint: AgentCheckpoint,
) -> Pin<Box<dyn Future<Output = Result<AgentExecutionDecision, AgentExecutorError>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn checkpoint<'life0, 'async_trait>(
&'life0 self,
checkpoint: AgentCheckpoint,
) -> Pin<Box<dyn Future<Output = Result<AgentExecutionDecision, AgentExecutorError>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Persist or inspect a checkpoint and decide whether execution should continue.
Provided Methods
Sourcefn requires_durable_hitl_preparation(&self) -> bool
fn requires_durable_hitl_preparation(&self) -> bool
Return whether sessions using this executor must route HITL effects through durable continuation preparation and exclusive started-claim authorization.
This property is intentionally sticky when an agent replaces executors so a cloned or restored store-backed agent cannot downgrade its effect boundary.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".