Module graph

Module graph 

Deterministic agent-loop graph transitions.

Structs

AgentGraphStep
One inspected graph transition.
AgentGraphTrace
A compact graph inspection report.
GraphDecision
Pure graph transition decision.

Enums

AgentNode
Agent runtime graph node.
GraphError
Graph transition error.

Functions

inspect_graph
Walk graph transitions for inspection using a static state snapshot.
inspect_next_node
Inspect the next graph transition from a node and state.
next_node
Determine the next graph node from current node and state.