pub struct OutputMedia {
pub url: String,
pub media_type: String,
}Expand description
Media/file output returned by the model.
Fields
url: StringOutput URL or provider resource URI.
media_type: StringMedia type reported by the provider.
Implementations
Sourceimpl OutputMedia
impl OutputMedia
Sourcepub fn new(url: impl Into<String>, media_type: impl Into<String>) -> Self
pub fn new(url: impl Into<String>, media_type: impl Into<String>) -> Self
Build an output media wrapper.
Sourcepub fn is_file(&self) -> bool
pub fn is_file(&self) -> bool
Return true when this media output looks like a document or generic file.
Sourcepub fn from_response_part(part: &ModelResponsePart) -> Option<Self>
pub fn from_response_part(part: &ModelResponsePart) -> Option<Self>
Build an output media wrapper from a canonical model response part.