Module stream

Module stream 

Runtime stream-result type and compatibility exports for raw stream protocol records.

Structs

AgentSidebandEvent
Typed view of an application sideband event carried by AgentStreamEvent::Custom.
AgentStreamRecord
Sequenced stream event record.
AgentStreamResult
Result returned by collection-based stream runs.
AgentStreamSink
In-memory sink used by tools that need to merge child stream records into the parent stream.
AgentStreamSource
Source attribution for records merged from nested agent runs.

Enums

AgentSidebandEventCategory
Stable category for context sideband events that are bridged into the runtime stream.
AgentStreamEvent
Typed event emitted by the agent runtime while a run progresses.
AgentStreamSourceKind
Origin type for a stream record emitted by a nested runtime component.