pub struct AgentStreamSource {
pub kind: AgentStreamSourceKind,
pub agent_id: AgentId,
pub agent_name: String,
pub task_id: Option<TaskId>,
pub run_id: Option<RunId>,
pub parent_run_id: Option<RunId>,
pub source_sequence: usize,
}Expand description
Source attribution for records merged from nested agent runs.
Fields
kind: AgentStreamSourceKindSource category.
agent_id: AgentIdSource agent identifier.
agent_name: StringHuman-readable source agent name.
task_id: Option<TaskId>Delegated task identifier when the source is task scoped.
run_id: Option<RunId>Source run identifier when known.
parent_run_id: Option<RunId>Parent run identifier when known.
source_sequence: usizeOriginal sequence number in the source run before parent stream rebasing.
Implementations