pub struct AgentSidebandEvent {
pub category: AgentSidebandEventCategory,
pub kind: String,
pub payload: Value,
pub metadata: Map<String, Value>,
}Expand description
Typed view of an application sideband event carried by AgentStreamEvent::Custom.
Fields
category: AgentSidebandEventCategoryStable event category.
kind: StringEvent type.
payload: ValueEvent payload.
metadata: Map<String, Value>Event metadata.
Implementations
Sourceimpl AgentSidebandEvent
impl AgentSidebandEvent
Sourcepub fn from_agent_event(event: &AgentEvent) -> Option<AgentSidebandEvent>
pub fn from_agent_event(event: &AgentEvent) -> Option<AgentSidebandEvent>
Build a typed sideband event when the context event kind belongs to the stable taxonomy.
Sourcepub fn category_for_kind(kind: &str) -> Option<AgentSidebandEventCategory>
pub fn category_for_kind(kind: &str) -> Option<AgentSidebandEventCategory>
Classify a context event kind into the stable sideband taxonomy.