AgentExecutor

Trait AgentExecutor 

pub trait AgentExecutor: Send + Sync {
    // Required method
    fn checkpoint<'life0, 'async_trait>(
        &'life0 self,
        checkpoint: AgentCheckpoint,
    ) -> Pin<Box<dyn Future<Output = Result<AgentExecutionDecision, AgentExecutorError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Fine-grained executor hook for persistence, interruption, and durable scheduling.

Required Methods

fn checkpoint<'life0, 'async_trait>( &'life0 self, checkpoint: AgentCheckpoint, ) -> Pin<Box<dyn Future<Output = Result<AgentExecutionDecision, AgentExecutorError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Persist or inspect a checkpoint and decide whether execution should continue.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors