Deterministic agent-loop graph transitions.
Structs
- Agent
Graph Step - One inspected graph transition.
- Agent
Graph Trace - A compact graph inspection report.
- Graph
Decision - Pure graph transition decision.
Enums
- Agent
Node - Agent runtime graph node.
- Graph
Error - Graph transition error.
Functions
- inspect_
graph - Walk graph transitions for inspection using a static state snapshot.
- inspect_
next_ node - Inspect the next graph transition from a node and state.
- next_
node - Determine the next graph node from current node and state.