pub fn inspect_next_node(
current: AgentNode,
state: &AgentRunState,
max_steps: usize,
) -> Result<AgentGraphStep, GraphError>Expand description
Inspect the next graph transition from a node and state.
Errors
Returns an error when the current node requires state produced by an earlier handler.