pub fn next_node(
current: AgentNode,
state: &AgentRunState,
max_steps: usize,
) -> Result<GraphDecision, GraphError>Expand description
Determine the next graph node from current node and state.
Errors
Returns an error when the current node requires state produced by an earlier handler.